pub enum DecoderError {
EoiOnFecPacket,
DuplicatedEoi,
NumSystematicMismatch,
UnknownNumSystematic,
EoiFecMismatch,
NotEnoughInput,
OutputTooShort,
WrongSystematicId,
MultipleImageIds,
InconsistentFlags,
DimensionsMismatch,
NoSystematic,
}Expand description
Error produced by the SSDV FEC decoder.
This enum lists the errors that can be produced by Decoder.
Variants
EoiOnFecPacket
The EOI flag is set on a FEC packet.
DuplicatedEoi
The EOI flag is set on several different systematic packets.
NumSystematicMismatch
There are different FEC packets containing a different value in the number of systematic packets field.
UnknownNumSystematic
The number of systematic packets in the image could not be determined.
This happens if the last systematic packet (carrying the EOI flag) is missing and there are no FEC packets.
EoiFecMismatch
There is a mismatch between the packet ID of the packet carrying the EOI flag and the number of systematic packets field in the FEC packets.
NotEnoughInput
There are not enough input packets for decoding.
The decoder needs as least as many distinct input packets as systematic packets are there in the image.
OutputTooShort
The output buffer is too short.
The length of the output buffer must be greater or equal than the number of systematic packets in the image.
WrongSystematicId
A systematic packet has a wrong packet ID.
MultipleImageIds
There are multiple image IDs in the packets.
InconsistentFlags
There are different packets with inconsistent values of the flags field.
DimensionsMismatch
There are systematic packets with different values of the image width or height.
NoSystematic
There are no systematic packets.
At least one systematic packet is required to obtain the image width and height.