SSDVPacketArray

Struct SSDVPacketArray 

#[repr(transparent)]
pub struct SSDVPacketArray<P: SSDVParameters>(pub GenericArray<u8, P::PacketLen>);
SSDV packet stored in a GenericArray.

This struct stores an SSDV packet in a GenericArray transparently (so the packet has the same ABI as an array [u8; N]). The struct implements the SSDVPacket trait by using the parameters defined in the SSDVParameters implementation of the type parameter P.

Tuple Fields

0: GenericArray<u8, P::PacketLen>

Implementations

Source

impl<P: SSDVParameters> SSDVPacketArray<P>

pub fn new_from_slice(slice: &[u8]) -> Result<Self, LengthError>

Creates a new SSDV packet from a slice.

This function creates a new SSDV packet by copying the data in slice. If the length of slice is different from the SSDV packet length specified by P::PacketLen, an error is returned.